HiveConfigStorageImpl class
Hive 配置存储实现类。
使用 Hive 数据库实现配置的存储和管理。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteAllValues(
) → Future< void> -
清空所有存储的键值。
override
-
deleteValue(
String key) → Future< void> -
删除指定 key 的值。
override
-
getValue<
T> (String key, Type type) → T -
获取指定 key 的值。
override
-
hasValue(
String key) → bool -
判断指定 key 是否存在。
override
-
init(
String configName) → Future< void> -
初始化存储实例。
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
String key, Type type, Object value) → Future< void> -
设置指定 key 的值。
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited